@@ -1,5 +1,5 @@
 /* GdkGLExt - OpenGL Extension to GDK
- * Copyright (C) 2002-2003  Naofumi Yasufuku
+ * Copyright (C) 2002-2004  Naofumi Yasufuku
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -80,7 +80,7 @@ gdk_gl_config_impl_x11_class_init (GdkGLConfigImplX11Class *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_impl_x11_class_init ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
   parent_class = g_type_class_peek_parent (klass);
 
@@ -92,7 +92,7 @@ gdk_gl_config_impl_x11_finalize (GObject *object)
 {
   GdkGLConfigImplX11 *impl = GDK_GL_CONFIG_IMPL_X11 (object);
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_impl_x11_finalize ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
   XFree (impl->xvinfo);
 
@@ -112,6 +112,7 @@ gdk_gl_config_get_std_rgb_colormap (GdkScreen   *screen,
                                     XVisualInfo *xvinfo,
                                     gboolean     is_mesa_glx)
 {
+  GdkDisplay *display;
   Display *xdisplay;
   int screen_num;
   Window xroot_window;
@@ -120,11 +121,11 @@ gdk_gl_config_get_std_rgb_colormap (GdkScreen   *screen,
   XStandardColormap *standard_cmaps;
   int i, num_cmaps;
   GdkVisual *visual;
-  static Atom xa_hp_cr_maps = (Atom) -1;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_get_std_rgb_colormap ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
-  xdisplay = GDK_SCREEN_XDISPLAY (screen);
+  display = gdk_screen_get_display (screen);
+  xdisplay = GDK_DISPLAY_XDISPLAY (display);
   screen_num = xvinfo->screen;
   xroot_window = RootWindow (xdisplay, screen_num);
 
@@ -137,34 +138,34 @@ gdk_gl_config_get_std_rgb_colormap (GdkScreen   *screen,
    * the window.  If that colormap is not set, the output will look stripy.
    */
 
-  if (is_mesa_glx)
+  if (is_mesa_glx &&
+      xvinfo->visual->class == TrueColor &&
+      xvinfo->depth == 8)
     {
-      if (xa_hp_cr_maps == (Atom) -1)
-        xa_hp_cr_maps = XInternAtom (xdisplay, "_HP_RGB_SMOOTH_MAP_LIST", True);
+      Atom xa_hp_cr_maps;
 
-      if (xa_hp_cr_maps &&
-          xvinfo->visual->class == TrueColor &&
-          xvinfo->depth == 8)
+      GDK_GL_NOTE (MISC,
+        g_message (" -- Try to find a standard RGB colormap with HP Color Recovery"));
+
+      xa_hp_cr_maps = gdk_x11_get_xatom_by_name_for_display (display,
+                                                             "_HP_RGB_SMOOTH_MAP_LIST");
+
+      status = XGetRGBColormaps (xdisplay, xroot_window,
+                                 &standard_cmaps, &num_cmaps,
+                                 xa_hp_cr_maps);
+      if (status)
         {
-          GDK_GL_NOTE (MISC,
-            g_message (" -- Try to find a standard RGB colormap with HP Color Recovery"));
-
-          status = XGetRGBColormaps (xdisplay, xroot_window,
-                                     &standard_cmaps, &num_cmaps,
-                                     xa_hp_cr_maps);
-          if (status)
+          for (i = 0; i < num_cmaps; i++)
             {
-              for (i = 0; i < num_cmaps; i++)
+              if (standard_cmaps[i].visualid == xvinfo->visualid)
                 {
-                  if (standard_cmaps[i].visualid == xvinfo->visualid)
-                    {
-                      xcolormap = standard_cmaps[i].colormap;
-                      break;
-                    }
+                  xcolormap = standard_cmaps[i].colormap;
+                  break;
                 }
-              XFree (standard_cmaps);
             }
 
+          XFree (standard_cmaps);
+
           if (xcolormap != None)
             {
               GDK_GL_NOTE (MISC,
@@ -215,15 +216,16 @@ gdk_gl_config_get_std_rgb_colormap (GdkScreen   *screen,
                       break;
                     }
                 }
+
               XFree (standard_cmaps);
-            }
 
-          if (xcolormap != None)
-            {
-              GDK_GL_NOTE (MISC, g_message (" -- Colormap: standard RGB"));
+              if (xcolormap != None)
+                {
+                  GDK_GL_NOTE (MISC, g_message (" -- Colormap: standard RGB"));
 
-              visual = gdk_x11_screen_lookup_visual (screen, xvinfo->visualid);
-              return gdk_x11_colormap_foreign_new (visual, xcolormap);
+                  visual = gdk_x11_screen_lookup_visual (screen, xvinfo->visualid);
+                  return gdk_x11_colormap_foreign_new (visual, xcolormap);
+                }
             }
         }
     }
@@ -252,7 +254,7 @@ gdk_gl_config_setup_colormap (GdkScreen   *screen,
   GdkGLOverlayInfo overlay_info;
   gboolean overlay_supported;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_setup_colormap ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
   if (is_rgba)
     {
@@ -295,7 +297,7 @@ gdk_gl_config_setup_colormap (GdkScreen   *screen,
 
       visual = gdk_x11_screen_lookup_visual (screen, xvinfo->visualid);
 
-      overlay_supported = _gdk_x11_gl_overlay_get_info (screen, visual, &overlay_info);
+      overlay_supported = _gdk_x11_gl_overlay_get_info (visual, &overlay_info);
       if (overlay_supported &&
           overlay_info.transparent_type == GDK_GL_OVERLAY_TRANSPARENT_PIXEL &&
           overlay_info.value < (guint32) xvinfo->visual->map_entries)
@@ -350,7 +352,7 @@ gdk_gl_config_setup_colormap (GdkScreen   *screen,
   GdkGLOverlayInfo overlay_info;
   gboolean overlay_supported;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_setup_colormap ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
   if (is_rgba)
     {
@@ -387,7 +389,7 @@ gdk_gl_config_setup_colormap (GdkScreen   *screen,
 
       visual = gdkx_visual_get (xvinfo->visualid);
 
-      overlay_supported = _gdk_x11_gl_overlay_get_info (screen, visual, &overlay_info);
+      overlay_supported = _gdk_x11_gl_overlay_get_info (visual, &overlay_info);
       if (overlay_supported &&
           overlay_info.transparent_type == GDK_GL_OVERLAY_TRANSPARENT_PIXEL &&
           overlay_info.value < xvinfo->visual->map_entries)
@@ -496,7 +498,7 @@ gdk_gl_config_new_common (GdkScreen *screen,
   XVisualInfo *xvinfo;
   int is_rgba;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_gl_config_new_common ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
 #ifdef GDKGLEXT_MULTIHEAD_SUPPORT
   xdisplay = GDK_SCREEN_XDISPLAY (screen);
@@ -512,7 +514,7 @@ gdk_gl_config_new_common (GdkScreen *screen,
    * Find an OpenGL-capable visual.
    */
 
-  GDK_GL_NOTE (IMPL, g_message (" * glXChooseVisual ()"));
+  GDK_GL_NOTE_FUNC_IMPL ("glXChooseVisual");
 
   xvinfo = glXChooseVisual (xdisplay, screen_num, (int *) attrib_list);
   if (xvinfo == NULL)
@@ -590,7 +592,7 @@ gdk_gl_config_new (const int *attrib_list)
 {
   GdkScreen *screen;
 
-  GDK_GL_NOTE (FUNC, g_message (" - gdk_gl_config_new ()"));
+  GDK_GL_NOTE_FUNC ();
 
   g_return_val_if_fail (attrib_list != NULL, NULL);
 
@@ -620,7 +622,7 @@ GdkGLConfig *
 gdk_gl_config_new_for_screen (GdkScreen *screen,
                               const int *attrib_list)
 {
-  GDK_GL_NOTE (FUNC, g_message (" - gdk_gl_config_new_for_screen ()"));
+  GDK_GL_NOTE_FUNC ();
 
   g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
   g_return_val_if_fail (attrib_list != NULL, NULL);
@@ -642,7 +644,7 @@ gdk_x11_gl_get_xvinfo (Display  *xdisplay,
   XVisualInfo *xvinfo_list;
   int nitems_return;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_x11_gl_get_xvinfo ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
   xvinfo_template.visualid = xvisualid;
   xvinfo_template.screen = screen_num;
@@ -670,7 +672,7 @@ gdk_x11_gl_config_new_from_visualid_common (GdkScreen *screen,
   XVisualInfo *xvinfo;
   int is_rgba;
 
-  GDK_GL_NOTE (FUNC, g_message (" -- gdk_x11_gl_config_new_from_visualid_common ()"));
+  GDK_GL_NOTE_FUNC_PRIVATE ();
 
 #ifdef GDKGLEXT_MULTIHEAD_SUPPORT
   xdisplay = GDK_SCREEN_XDISPLAY (screen);
@@ -761,7 +763,7 @@ gdk_x11_gl_config_new_from_visualid (VisualID xvisualid)
 {
   GdkScreen *screen;
 
-  GDK_GL_NOTE (FUNC, g_message (" - gdk_x11_gl_config_new_from_visualid ()"));
+  GDK_GL_NOTE_FUNC ();
 
 #ifdef GDKGLEXT_MULTIHEAD_SUPPORT
   screen = gdk_screen_get_default ();
@@ -788,7 +790,7 @@ GdkGLConfig *
 gdk_x11_gl_config_new_from_visualid_for_screen (GdkScreen *screen,
                                                 VisualID   xvisualid)
 {
-  GDK_GL_NOTE (FUNC, g_message (" - gdk_x11_gl_config_new_from_visualid_for_screen ()"));
+  GDK_GL_NOTE_FUNC ();
 
   g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
 
